@@ -8,9 +8,10 @@
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Scroll;
-$ElasticSearchX::Model::Scroll::VERSION = '1.0.3';
+$ElasticSearchX::Model::Scroll::VERSION = '2.0.0';
 use Moose;
-use Search::Elasticsearch::Scroll;
+
+use ElasticSearchX::Model::Document::Types qw(ESScroll);
 
 has scroll => ( is => 'ro', isa => 'Str', required => 1, default => '1m' );
 
@@ -23,7 +24,7 @@ has set => (
 
 has _scrolled_search => (
     is         => 'ro',
-    isa        => 'Search::Elasticsearch::Scroll',
+    isa        => ESScroll,
     lazy_build => 1,
     handles    => {
         _next     => 'next',
@@ -39,15 +40,12 @@ has qs => (
 
 sub _build__scrolled_search {
     my $self = shift;
-    Search::Elasticsearch::Scroll->new(
-        {
-            es     => $self->set->es,
-            body   => $self->set->_build_query,
-            scroll => $self->scroll,
-            index  => $self->index->name,
-            type   => $self->type->short_name,
-            %{ $self->qs || {} },
-        }
+    $self->set->es->scroll_helper(
+        body   => $self->set->_build_query,
+        scroll => $self->scroll,
+        index  => $self->index->name,
+        type   => $self->type->short_name,
+        %{ $self->qs || {} },
     );
 }
 
@@ -72,7 +70,7 @@ ElasticSearchX::Model::Scroll
 
 =head1 VERSION
 
-version 1.0.3
+version 2.0.0
 
 =head1 SYNOPSIS
 
